Root

Struct Root 

pub struct Root {
    pub arguments: Arguments,
    pub asset_index: AssetIndex,
    pub assets: String,
    pub downloads: HashMap<String, DownloadData>,
    pub id: String,
    pub java_version: JavaVersion,
    pub libraries: Box<[Library]>,
    pub inherits_from: Option<String>,
    pub main_class: String,
    pub version_type: String,
}
This struct represent a .json file inside minecraft_root/versions/{version_name}/{version_name}.json

Careful: inherits_from indicates that it should inherit the values from other version. (The values must be added and not overwrite the current data)

This struct is also the repr of minecraft version from piston-meta.

This struct will be used when launching minecraft from the command line and/or when downloading a new minecraft profile from piston-meta.

JSON EXAMPLE

An example of the outter JSON might looks like this:

{
    arguments: {…},
    assetIndex: {…},
    assets: "19",
    complianceLevel: 1,
    downloads: {…},
    id: "1.21.4",
    javaVersion: {…},
    libraries: […],
    logging: {…},
    mainClass: "net.minecraft.client.main.Main",
    minimumLauncherVersion: 21,
    type: "release"
}

The fields are renamed to snake_case and type -> version_type since type is a keyword.

Downloading minecraft yay !

When using this struct to download a new minecraft version fields of insterest are:

  • asset_index
  • assets
  • libraries
  • downloads
  • java_version (In case Java is not installed)

You will find urls to file/files you need in order to run minecraft.

Launching minecraft !

So in order to launch minecraft you will need to read a file from minecraft_root/versions/{version_name}/{version_name}.json

This file contains a JSON with this struct. You will need the following fields in order to launch minecraft:

  • arguments
  • assets
  • java_version (In case Java is not installed or you want the custom runtime)
  • libraries (you must add them to java path -cp)
  • main_class
  • logging (Not mandatory but usefull)

I KNOW TIME AND RELEASETIME FIELDS ARE MISSING, NEED THEM ? PR !!!!

Fields

arguments: Argumentsasset_index: AssetIndexassets: Stringdownloads: HashMap<String, DownloadData>

.minecraft/versions/version/version.jar

id: String

Actual version example: 1.21.7

java_version: JavaVersionlibraries: Box<[Library]>inherits_from: Option<String>main_class: Stringversion_type: String

Implementations