RinthProject

Struct RinthProject 

pub struct RinthProject {
Show 22 fields pub slug: String, pub title: String, pub description: String, pub categories: Box<[String]>, pub client_side: String, pub server_side: String, pub body: String, pub status: String, pub requested_status: Option<String>, pub additional_categories: Box<[String]>, pub project_type: String, pub downloads: u32, pub icon_url: Option<String>, pub id: String, pub team: String, pub body_url: Option<String>, pub published: String, pub updated: String, pub followers: u32, pub versions: Box<[String]>, pub game_versions: Box<[String]>, pub loaders: Box<[String]>,
}
A project returned from the API

API Request

Get a project

GET https://api.modrinth.com/v2/project/{id | slug}

Parameters

  • id|slug String (Required)

This type is also usable when requesting searches for rinth api

Missing fields

  • issues_url
  • source_url
  • wiki_url
  • discord_url
  • donation_url
  • color
  • thread_id
  • monetization_status
  • moderator message
  • approved
  • queued
  • license
  • gallery

Want any of them ? PR !!!

Fields

slug: String

The slug of a project, used for vanity URLs. Regex: ^[\w!@$()`.+,“-’]{3,64}$

title: Stringdescription: Stringcategories: Box<[String]>client_side: String

Allowed values: required optional unsupported unknown

server_side: String

Allowed values: required optional unsupported unknown

body: Stringstatus: String

Allowed values: approved archived rejected draft unlisted processing withheld scheduled private unknown

requested_status: Option<String>

Allowed values: approved archived unlisted private draft

additional_categories: Box<[String]>

A list of categories which are searchable but non-primary.

project_type: String

Allowed values: mod modpack resourcepack shader

downloads: u32icon_url: Option<String>id: Stringteam: Stringbody_url: Option<String>

The link to the long description of the project. Always null, only kept for legacy compatibility.

published: String

format: ISO-8601

updated: String

format: ISO-8601

followers: u32versions: Box<[String]>

A list of the version IDs of the project (will never be empty unless draft status)

game_versions: Box<[String]>

A list of all of the game versions supported by the project

loaders: Box<[String]>